@@ -435,7 +435,7 @@ void thexpmap::export_kml(class thdb2dxm * maps, class thdb2dprj * prj)
   }
 
   if (maps == NULL) {
-    thwarning(("%s [%d] -- no selected projection data -- %s",
+    thwarning(("%s [%lu] -- no selected projection data -- %s",
       this->src.name, this->src.line, this->projstr))
     return;
   }
@@ -628,7 +628,7 @@ void thexpmap::export_bbox(class thdb2dxm * maps, class thdb2dprj * prj)
   }
 
   if (maps == NULL) {
-    thwarning(("%s [%d] -- no selected projection data -- %s",
+    thwarning(("%s [%lu] -- no selected projection data -- %s",
       this->src.name, this->src.line, this->projstr))
     return;
   }
@@ -721,7 +721,7 @@ void thexpmap::export_dxf(class thdb2dxm * maps, class thdb2dprj * /*prj*/) // T
 {
 
   if (maps == NULL) {
-    thwarning(("%s [%d] -- no selected projection data -- %s",
+    thwarning(("%s [%lu] -- no selected projection data -- %s",
       this->src.name, this->src.line, this->projstr))
     return;
   }
