@@ -32,6 +32,7 @@
 #include "thdata.h"
 #include "thsurvey.h"
 #include "thendsurvey.h"
+#include "thdatabase.h"
 #include "extern/img.h"
 #include <string.h>
 #include <string>
@@ -39,6 +40,8 @@
 #include <list>
 #include <filesystem>
 
+#include <fmt/printf.h>
+
 struct thsst {
   std::string name, fullname;
   thsurvey * survey;  
@@ -435,15 +438,12 @@ void thimport::import_file_img()
   if (this->filter != NULL)
     filterl = strlen(this->filter);
   thbuffer n1, n2;
-  thbuffer xb, yb, zb;
-    xb.guarantee(128);
-    yb.guarantee(128);
-    zb.guarantee(128);
+  std::string xb, yb, zb;
   std::string orig_name, new_name;  
   img* pimg = img_open(this->fname);
   if (pimg == NULL) {	
     imgerr = img_error();
-    ththrow("unable to open file {}, error code: {}", this->fname, imgerr);
+    ththrow("unable to open file {}, error code: {}", this->fname, static_cast<int>(imgerr));
   }
   do {
     result = img_read_item(pimg, &imgpt);
@@ -479,9 +479,9 @@ void thimport::import_file_img()
         if (strlen(stnm) < 1)
           break;
         if (svxs2ths.find(orig_name) == svxs2ths.end()) {
-          sprintf(xb.get_buffer(), "%.16g", imgpt.x + this->calib_x);
-          sprintf(yb.get_buffer(), "%.16g", imgpt.y + this->calib_y);
-          sprintf(zb.get_buffer(), "%.16g", imgpt.z + this->calib_z);
+          xb = fmt::sprintf("%.16g", imgpt.x + this->calib_x);
+          yb = fmt::sprintf("%.16g", imgpt.y + this->calib_y);
+          zb = fmt::sprintf("%.16g", imgpt.z + this->calib_z);
           tmpsurvey = this->db->csurveyptr;
           new_name = this->station_name(stnm, pimg->separator, &tmpsst);
           // thprintf("%s -> %s\n", pimg->label, new_name.c_str());
@@ -508,9 +508,9 @@ void thimport::import_file_img()
           tmpsst.fullname = new_name;
           svxpos2ths[tmppos] = tmpsst;
           svxs2ths[orig_name] = new_name;
-          args[1] = xb.get_buffer();
-          args[2] = yb.get_buffer();
-          args[3] = zb.get_buffer();
+          args[1] = xb.data();
+          args[2] = yb.data();
+          args[3] = zb.data();
           args[0] = n1.get_buffer();
           tmpdata->cs = this->cs;
           tmpdata->set_data_fix(4, args);
@@ -540,7 +540,7 @@ void thimport::import_file_img()
   img_close(pimg);
 
   if (notimpst > 0) {
-    thwarning(("unable to import %d stations outside survey", notimpst));
+    thwarning(("unable to import %lu stations outside survey", notimpst));
   }
 
   thsurvey * s1survey, * s2survey;
@@ -653,7 +653,7 @@ void thimport::import_file_img()
   }
 
   if (notimpsh > 0) {
-    thwarning(("unable to import %d shots outside survey", notimpsh));
+    thwarning(("unable to import %lu shots outside survey", notimpsh));
   }
 
 }
