@@ -784,7 +784,7 @@ void thdecode_utf2tex(thbuffer * dest, const char * src)
         isutf8 = isutf8 || (*tmpp > 127);
       }
       if (isutf8) {
-        dest->strcat(utf2tex((char*) wsrcp));
+        dest->strcat(utf2tex((char*) wsrcp).c_str());
       } else {
         dest->strcat((char*) wsrcp);
       }
