@@ -21,6 +21,10 @@
 #ifndef thsvg_h
 #define thsvg_h
 
-void thsvg(char * fname);
+#include "thlegenddata.h"
+
+void thsvg(const char * fname, int, const legenddata& ldata);
+
+std::string escape_html(std::string);
 
 #endif
